Module interaction

Module interaction 

Contains some structs and functions that are used when interacting with the layout, like swapping two keys.

Structs

KeyPos
Represents a layer name along with a row and column on a keyboard. Can also be created by (name, Pos).into() or (name, (row, col)).into().
Pos
Represents a (row, column) position on a keyboard. Can be created by (num, num).into().