Anchor

Struct Anchor 

pub struct Anchor(/* private fields */);
An anchor represents where the top left key on a Dof is compared to where it would be on a physical keyboard. For example, if you were to provide a 3x10 raster of letters but would like this applied to an ANSI keyboard, the Anchor would be (1, 1), as the top left corner of the Dof (being where qwerty q is) would need to be shifted one left and one up to be in the top left corner of the physical keyboard. Therefore, the default value of an anchor is dependent on the physical keyboard it is applied to.

Implementations

Source

impl Anchor

pub const fn new(x: u8, y: u8) -> Self

Create a new anchor

pub const fn x(&self) -> usize

Return the x coordinate as usize

pub const fn y(&self) -> usize

Return the y coordinate as usize