Struct libdof::DescriptiveKey

source ·
pub struct DescriptiveKey { /* private fields */ }
A Key with metadata attached. These are produced by calling Dof::keys().

Implementations

source

impl DescriptiveKey

source

pub fn new( output: Key, layer: String, row: usize, col: usize, finger: Finger ) -> Self

source

pub fn keypos(&self) -> KeyPos

Get the KeyPos of a certain key, containing the layer name as well its row and column coordinates.

source

pub fn pos(&self) -> Pos

Get the key’s row and column.

source

pub fn row(&self) -> usize

Get the key’s row.

source

pub fn col(&self) -> usize

Get the key’s column.

source

pub fn finger(&self) -> Finger

Get the finger the key is supposed to be pressed with.

source

pub fn output(&self) -> &Key

Get the key’s output.

source

pub fn layer_name(&self) -> &str

Get the name of the layer of the key.

source

pub fn is_on_finger(&self, finger: Finger) -> bool

Check if the key is on a certain finger.

source

pub fn is_on_fingers(&self, fingers: &[Finger]) -> bool

Check if the key is on any of the provided fingers.

source

pub fn is_on_left_hand(&self) -> bool

Check if the key is on left hand, including left thumb.

source

pub fn is_on_layer(&self, layer: &str) -> bool

Check if the key is on a specific layer.

source

pub fn is_char_key(&self) -> bool

Check if the key is of type Key::Char which outputs a single character.

source

pub fn is_word_key(&self) -> bool

Check if the key is of type Key::Word which outputs a specific string.

source

pub fn is_empty_key(&self) -> bool

Check if the key is of type Key::Empty which doesn’t output anything.

source

pub fn is_transparent_key(&self) -> bool

Check if the key is of type Key::Transparent which outputs whatever it is the main layer outputs in that position.

source

pub fn is_layer_key(&self) -> bool

Check if the key is of type Key::Layer which holds the name. of a layer on the layout

source

pub fn char_output(&self) -> Option<char>

Get the output if the key is of type Key::Char.

source

pub fn word_output(&self) -> Option<&str>

Get the output if the key is of type Key::Word.

source

pub fn layer_output(&self) -> Option<&str>

Get the layer name if the key is of type Key::Layer.